@@ -78,6 +78,7 @@ static void update_arena (void);
 static gint timeout_cb (void *data);
 static void destroy_game_timer (void);
 static void create_game_timer (void);
+void init_keyboard (void);
 static void move_all_robots (void);
 static void move_type2_robots (void);
 static void move_robots (void);
@@ -164,7 +165,8 @@ log_score (gint sc)
                        game_config_filename (current_game_config ()));
   } else {
     sbuf =
-      g_strdup_printf ("%s", game_config_filename (current_game_config ()));
+      g_strdup_printf ("%s",
+                       game_config_filename (current_game_config ()));
   }
 
   if (sc != 0) {
@@ -272,7 +274,7 @@ clear_arena (void)
  * load_temp_arena
  *
  * Description:
- * Set up the temporary arena for processing speculative moves. 
+ * Set up the temporary arena for processing speculative moves.
  *
  **/
 static void
@@ -339,8 +341,7 @@ generate_level (void)
   if (num_robots1 > MAX_ROBOTS) {
     current_level = 0;
     num_robots1 = game_config ()->initial_type1;
-    message_box (_
-                 ("Congratulations, You Have Defeated the Robots!! \nBut Can You do it Again?"));
+    message_box (_("Congratulations, You Have Defeated the Robots!! \nBut Can You do it Again?"));
     play_sound (SOUND_VICTORY);
   }
 
@@ -355,8 +356,7 @@ generate_level (void)
     current_level = 0;
     num_robots1 = game_config ()->initial_type1;
     num_robots2 = game_config ()->initial_type2;
-    message_box (_
-                 ("Congratulations, You Have Defeated the Robots!! \nBut Can You do it Again?"));
+    message_box (_("Congratulations, You Have Defeated the Robots!! \nBut Can You do it Again?"));
     play_sound (SOUND_VICTORY);
   }
 
@@ -543,6 +543,24 @@ create_game_timer (void)
 }
 
 
+/**
+ * init_keyboard
+ *
+ * Description:
+ * Initialises the keyboard actions when the game first starts up
+ **/
+void
+init_keyboard (void)
+{
+  GtkEventController *key_controller;
+
+  key_controller = gtk_event_controller_key_new (window);
+
+  g_signal_connect (G_OBJECT (key_controller), "key-pressed",
+                    G_CALLBACK (keyboard_cb), 0);
+}
+
+
 /**
  * init_game
  *
@@ -554,8 +572,7 @@ init_game (void)
 {
   create_game_timer ();
 
-  g_signal_connect (GTK_WIDGET (window), "key_press_event",
-                    G_CALLBACK (keyboard_cb), 0);
+  init_keyboard ();
 
   start_new_game ();
 }
@@ -1296,7 +1313,7 @@ get_dir (int ix, int iy, int *odx, int *ody)
 
   angle = atan2 (dy, dx);
 
-  /* Note the adjustment we have to make (+9, not +8) because atan2's idea 
+  /* Note the adjustment we have to make (+9, not +8) because atan2's idea
    * of octants and the ones we want are shifted by PI/8. */
   octant = (((int) floor (8.0 * angle / M_PI) + 9) / 2) % 8;
 
@@ -1304,33 +1321,40 @@ get_dir (int ix, int iy, int *odx, int *ody)
   *ody = movetable[octant][1];
 }
 
-gboolean
-mouse_cb (GtkWidget * widget, GdkEventButton * e, gpointer data)
+void
+mouse_cb (GtkGestureMultiPress *gesture,
+          gint                  n_press,
+          gdouble               x,
+          gdouble               y,
+          gpointer              user_data)
 {
   int dx, dy;
 
   if (game_state != STATE_PLAYING)
-    return TRUE;
+    return;
 
-  get_dir (e->x, e->y, &dx, &dy);
+  get_dir ((int)x, (int)y, &dx, &dy);
 
   if (player_move (dx, dy)) {
     move_robots ();
   }
 
-  return TRUE;
+  return;
 }
 
-gboolean
-move_cb (GtkWidget * widget, GdkEventMotion * e, gpointer data)
+void
+move_cb (GtkEventControllerMotion *controller,
+         gdouble                   x,
+         gdouble                   y,
+         gpointer                  user_data)
 {
   int dx, dy;
 
-  get_dir (e->x, e->y, &dx, &dy);
+  get_dir ((int)x, (int)y, &dx, &dy);
 
-  set_cursor_by_direction (gtk_widget_get_window (widget), dx, dy);
+  set_cursor_by_direction (gtk_widget_get_window (game_area), dx, dy);
 
-  return TRUE;
+  return;
 }
 
 /**********************************************************************/
